@@ -32,14 +32,32 @@
 #include <xf86Xinput.h>
 #include <xisb.h>
 
+#include "config.h"
+
+struct _SynapticsPrivateRec;
+typedef struct _SynapticsPrivateRec SynapticsPrivate;
+
+enum SynapticsSlotState
+{
+    SLOTSTATE_EMPTY = 0,
+    SLOTSTATE_OPEN,
+    SLOTSTATE_CLOSE,
+    SLOTSTATE_UPDATE,
+};
+
+/* used to mark emulated hw button state */
+#define BTN_EMULATED_FLAG 0x80
+
 /*
  * A structure to describe the state of the touchpad hardware (buttons and pad)
  */
 struct SynapticsHwState {
-    int millis;			/* Timestamp in milliseconds */
+    CARD32 millis;		/* Timestamp in milliseconds */
     int x;			/* X position of finger */
     int y;			/* Y position of finger */
     int z;			/* Finger pressure */
+    int cumulative_dx;		/* Cumulative delta X for clickpad dragging */
+    int cumulative_dy;		/* Cumulative delta Y for clickpad dragging */
     int numFingers;
     int fingerWidth;
 
@@ -51,11 +69,11 @@ struct SynapticsHwState {
     Bool multi[8];
     Bool middle;		/* Some ALPS touchpads have a middle button */
 
-    Bool guest_left;		/* guest device */
-    Bool guest_mid;
-    Bool guest_right;
-    int  guest_dx;
-    int  guest_dy;
+#ifdef HAVE_MULTITOUCH
+    int num_mt_mask;
+    ValuatorMask **mt_mask;
+    enum SynapticsSlotState *slot_state;
+#endif
 };
 
 struct CommData {
@@ -67,46 +85,41 @@ struct CommData {
     int protoBufTail;
 
     /* Used for keeping track of partial HwState updates. */
-    struct SynapticsHwState hwState;
+    struct SynapticsHwState *hwState;
     Bool oneFinger;
     Bool twoFingers;
     Bool threeFingers;
 };
 
-enum SynapticsProtocol {
-    SYN_PROTO_PSAUX,		/* Raw psaux device */
-#ifdef BUILD_EVENTCOMM
-    SYN_PROTO_EVENT,		/* Linux kernel event interface */
-#endif /* BUILD_EVENTCOMM */
-#ifdef BUILD_PSMCOMM
-    SYN_PROTO_PSM,		/* FreeBSD psm driver */
-#endif /* BUILD_PSMCOMM */
-    SYN_PROTO_ALPS		/* ALPS touchpad protocol */
-};
-
 struct _SynapticsParameters;
-struct SynapticsHwInfo;
-struct CommData;
 
 struct SynapticsProtocolOperations {
-    void (*DeviceOnHook)(LocalDevicePtr local, struct _SynapticsParameters *para);
-    void (*DeviceOffHook)(LocalDevicePtr local);
-    Bool (*QueryHardware)(LocalDevicePtr local);
-    Bool (*ReadHwState)(LocalDevicePtr local,
-			struct SynapticsProtocolOperations *proto_ops,
+    Bool (*DeviceOnHook)(InputInfoPtr pInfo, struct _SynapticsParameters *para);
+    Bool (*DeviceOffHook)(InputInfoPtr pInfo);
+    Bool (*QueryHardware)(InputInfoPtr pInfo);
+    Bool (*ReadHwState)(InputInfoPtr pInfo,
 			struct CommData *comm, struct SynapticsHwState *hwRet);
-    Bool (*AutoDevProbe)(LocalDevicePtr local);
-    void (*ReadDevDimensions)(LocalDevicePtr local);
+    Bool (*AutoDevProbe)(InputInfoPtr pInfo, const char *device);
+    void (*ReadDevDimensions)(InputInfoPtr pInfo);
 };
 
+#ifdef BUILD_PS2COMM
 extern struct SynapticsProtocolOperations psaux_proto_operations;
+extern struct SynapticsProtocolOperations alps_proto_operations;
+#endif /* BUILD_PS2COMM */
 #ifdef BUILD_EVENTCOMM
 extern struct SynapticsProtocolOperations event_proto_operations;
 #endif /* BUILD_EVENTCOMM */
 #ifdef BUILD_PSMCOMM
 extern struct SynapticsProtocolOperations psm_proto_operations;
 #endif /* BUILD_PSMCOMM */
-extern struct SynapticsProtocolOperations alps_proto_operations;
 
+extern struct SynapticsHwState *SynapticsHwStateAlloc(SynapticsPrivate *priv);
+extern void SynapticsHwStateFree(struct SynapticsHwState **hw);
+extern void SynapticsCopyHwState(struct SynapticsHwState *dst,
+                                 const struct SynapticsHwState *src);
+extern void SynapticsResetTouchHwState(struct SynapticsHwState *hw);
+
+extern Bool SynapticsIsSoftButtonAreasValid(int *values);
 
 #endif /* _SYNPROTO_H_ */
